@@ -117,6 +117,13 @@ class BlurPool(Algorithm):
             raise ValueError(
                 'Both replace_maxpool and replace_convs are set to False. BlurPool will not be modifying the model.')
 
+    def __repr__(self) -> str:
+        return f'{self.__class__.__name__}(replace_convs={self.replace_convs},replace_maxpools={self.replace_maxpools},blur_first={self.blur_first},min_channels={self.min_channels})'
+
+    @staticmethod
+    def required_on_load() -> bool:
+        return True
+
     def match(self, event: Event, state: State) -> bool:
         return event == Event.INIT
 
@@ -145,7 +152,7 @@ class BlurPool(Algorithm):
                  f'Model now has {num_blurpool_layers} BlurMaxPool2d '
                  f'and {num_blurconv_layers} BlurConv2D layers.')
 
-        logger.data_fit({
+        logger.log_hyperparameters({
             'blurpool/num_blurpool_layers': num_blurpool_layers,
             'blurpool/num_blurconv_layers': num_blurconv_layers,
         })
