@@ -24,26 +24,25 @@ class EarlyStopper(Callback):
     """Track a metric and halt training if it does not improve within a given interval.
 
     Example:
-        .. doctest::
+    .. doctest::
 
-            >>> from composer import Evaluator, Trainer
-            >>> from composer.callbacks.early_stopper import EarlyStopper
-            >>> from torchmetrics.classification.accuracy import Accuracy
-            >>> # constructing trainer object with this callback
-            >>> early_stopper = EarlyStopper("Accuracy", "my_evaluator", patience=1)
-            >>> evaluator = Evaluator(
-            ...     dataloader = eval_dataloader,
-            ...     label = 'my_evaluator',
-            ...     metrics = Accuracy()
-            ... )
-            >>> trainer = Trainer(
-            ...     model=model,
-            ...     train_dataloader=train_dataloader,
-            ...     eval_dataloader=evaluator,
-            ...     optimizers=optimizer,
-            ...     max_duration="1ep",
-            ...     callbacks=[early_stopper],
-            ... )
+        >>> from composer import Evaluator, Trainer
+        >>> from composer.callbacks.early_stopper import EarlyStopper
+        >>> # constructing trainer object with this callback
+        >>> early_stopper = EarlyStopper("Accuracy", "my_evaluator", patience=1)
+        >>> evaluator = Evaluator(
+        ...     dataloader = eval_dataloader,
+        ...     label = 'my_evaluator',
+        ...     metric_names = ['Accuracy']
+        ... )
+        >>> trainer = Trainer(
+        ...     model=model,
+        ...     train_dataloader=train_dataloader,
+        ...     eval_dataloader=evaluator,
+        ...     optimizers=optimizer,
+        ...     max_duration="1ep",
+        ...     callbacks=[early_stopper],
+        ... )
 
     Args:
         monitor (str): The name of the metric to monitor.
@@ -110,9 +109,12 @@ class EarlyStopper(Callback):
                 raise ValueError('If `patience` is an instance of Time, it must have units of EPOCH or BATCH.')
 
     def _get_monitored_metric(self, state: State):
-        if self.dataloader_label in state.current_metrics:
-            if self.monitor in state.current_metrics[self.dataloader_label]:
-                return state.current_metrics[self.dataloader_label][self.monitor]
+        if self.dataloader_label == 'train':
+            if self.monitor in state.train_metrics:
+                return state.train_metrics[self.monitor].compute()
+        else:
+            if self.monitor in state.eval_metrics[self.dataloader_label]:
+                return state.eval_metrics[self.dataloader_label][self.monitor].compute()
         raise ValueError(f"Couldn't find the metric {self.monitor} with the dataloader label {self.dataloader_label}."
                          "Check that the dataloader_label is set to 'eval', 'train' or the evaluator name.")
 
