@@ -19,19 +19,19 @@ from composer.core.state import State
 from composer.core.time import Time, Timestamp, TimeUnit, ensure_time
 
 __all__ = [
-    "Algorithm",
-    "Callback",
-    "DataSpec",
-    "ensure_data_spec",
-    "Engine",
-    "Trace",
-    "Evaluator",
-    "Event",
-    "Precision",
-    "State",
-    "Time",
-    "Timestamp",
-    "TimeUnit",
-    "ensure_time",
-    "ensure_evaluator",
+    'Algorithm',
+    'Callback',
+    'DataSpec',
+    'ensure_data_spec',
+    'Engine',
+    'Trace',
+    'Evaluator',
+    'Event',
+    'Precision',
+    'State',
+    'Time',
+    'Timestamp',
+    'TimeUnit',
+    'ensure_time',
+    'ensure_evaluator',
 ]
