@@ -37,6 +37,7 @@ These orderings are enforced by algorithm passes. The default passes registered
     * The design of :class:`.Engine` is subject to change in future releases
       to accommodate more complexity as we investigate composition of algorithms.
 
+To generate verbose debug logs for the engine, set the environment variable ``ENGINE_DEBUG=1``.
 
 Trace
 ~~~~~
@@ -65,6 +66,7 @@ from __future__ import annotations
 import atexit
 import contextlib
 import logging
+import os
 import weakref
 from collections import OrderedDict
 from dataclasses import dataclass
@@ -75,7 +77,7 @@ from composer.core.algorithm import Algorithm
 from composer.core.callback import Callback
 from composer.core.event import Event
 from composer.core.state import State
-from composer.loggers import Logger, LogLevel
+from composer.loggers import Logger
 from composer.profiler import ProfilerAction
 
 log = logging.getLogger(__name__)
@@ -334,17 +336,9 @@ class Engine():
                                      run=True)
 
         if self.logger is not None:
-            if event in (Event.INIT, Event.FIT_START):
-                log_level = LogLevel.FIT
-            if event in (Event.EPOCH_START, Event.EPOCH_END):
-                log_level = LogLevel.EPOCH
-            else:
-                # algs don't run on eval events, so don't have to worry about
-                # batch-frequency vs epoch-frequency evaluators
-                log_level = LogLevel.BATCH
             if len(trace) > 0:
-                self.logger.data(log_level=log_level,
-                                 data={f'{tr.name}/{tr.event}': 1 if tr.run else 0 for _, tr in trace.items()})
+                self.logger.log_traces(
+                    {f'algorithm_traces/{tr.name}/{tr.event}': 1 if tr.run else 0 for _, tr in trace.items()})
 
         return trace
 
@@ -432,7 +426,8 @@ class Engine():
 
         timestamp += f'[event={event.name}]'
 
-        log.debug(f'{timestamp}: {msg}')
+        if os.environ.get('ENGINE_DEBUG', None):
+            log.debug(f'{timestamp}: {msg}')
 
     def close(self) -> None:
         """Shutdown the engine.
