@@ -5,7 +5,6 @@
 
 from __future__ import annotations
 
-import copy
 import dataclasses
 import datetime
 import logging
@@ -15,9 +14,9 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Optional,
 
 import torch
 import yahp as hp
-from torchmetrics import Metric, MetricCollection
 
 import composer
+from composer import utils
 from composer.algorithms.algorithm_hparams_registry import algorithm_registry
 from composer.callbacks.callback_hparams_registry import callback_registry
 from composer.core import Algorithm, Callback, DataSpec, Evaluator, Event, Precision, State, Time
@@ -25,7 +24,7 @@ from composer.core.types import JSON, PyTorchScheduler
 from composer.datasets.dataset_hparams import DataLoaderHparams, DatasetHparams
 from composer.datasets.dataset_hparams_registry import dataset_registry
 from composer.datasets.evaluator_hparams import EvaluatorHparams
-from composer.loggers import LoggerDestination, LogLevel
+from composer.loggers import LoggerDestination
 from composer.loggers.logger_hparams_registry import logger_registry
 from composer.models import (BERTForClassificationHparams, BERTHparams, DeepLabV3Hparams, EfficientNetB0Hparams,
                              GPT2Hparams, MnistClassifierHparams, ModelHparams, ResNetCIFARHparams, ResNetHparams,
@@ -105,6 +104,20 @@ def _parse_grad_accum(grad_accum: Union[int, str]) -> Union[int, str]:
     raise ValueError('grad_accum should be "auto" or an integer.')
 
 
+def _parse_eval_batch_size(eval_batch_size: Optional[Union[int, str]]) -> Optional[Union[int, str]]:
+    if eval_batch_size is None:
+        return None
+    elif eval_batch_size == 'auto':
+        return eval_batch_size
+
+    try:
+        return int(eval_batch_size)
+    except (ValueError, TypeError):
+        pass
+
+    raise ValueError('eval_batch_size should be "auto" or an integer.')
+
+
 def _initialize_eval_dataloader(
     model: ComposerModel,
     eval_dataset_hparams: Optional[DatasetHparams],
@@ -161,7 +174,6 @@ class TrainerHparams(hp.Hparams):
         train_batch_size (int): The optimization batch size to use for training. This is the total batch
             size that is used to produce a gradient for the optimizer update step.
         train_subset_num_batches (int, optional): See :class:`.Trainer`.
-        compute_training_metrics (bool, optional): See :class:`.Trainer`.
 
         max_duration (str): The maximum duration to train as a str (e.g. ``1ep``, or ``10ba``).
             Will be converted to a :class:`~composer.core.Time` object.
@@ -194,8 +206,9 @@ class TrainerHparams(hp.Hparams):
             or more datasets. (default: ``None``)
 
             .. seealso:: :class:`~composer.core.evaluator.Evaluator` for more details on evaluators.
-        eval_batch_size (int, optional): The batch size to use for evaluation. Must be provided if one of
-            ``val_dataset`` or ``evaluators`` is set. (default: ``None``)
+        eval_batch_size (int | str, optional): The batch size to use for evaluation. Must be provided if one of
+            ``val_dataset`` or ``evaluators`` is set. If set to ``auto``, which requires ``grad_accum='auto'``,
+            train_batch_size is used with microbatches to avoid Cuda OOMs. (default: ``None``)
         eval_interval (str, optional): See :class:`.Trainer`.
         eval_subset_num_batches (int, optional): See :class:`.Trainer`.
 
@@ -211,7 +224,6 @@ class TrainerHparams(hp.Hparams):
         run_name (str, optional): See :class:`.Trainer`.
         progress_bar (bool, optional): See :class:`.Trainer`.
         log_to_console (bool, optional): See :class:`.Trainer`.
-        console_log_level (bool, optional): See :class:`.Trainer`.
         console_stream (bool, optional): See :class:`.Trainer`.
         python_log_level (str): The Python log level to use for log statements in the :mod:`composer`
             module. (default: ``INFO``)
@@ -290,7 +302,6 @@ class TrainerHparams(hp.Hparams):
         default=None,
     )
     train_subset_num_batches: int = hp.auto(Trainer, 'train_subset_num_batches')
-    compute_training_metrics: bool = hp.auto(Trainer, 'compute_training_metrics')
 
     # Stopping Conditions
     max_duration: Optional[Union[str, int]] = hp.auto(Trainer, 'max_duration')
@@ -307,7 +318,8 @@ class TrainerHparams(hp.Hparams):
     # Evaluation
     val_dataset: Optional[DatasetHparams] = hp.optional(doc='Validation dataset hparams', default=None)
     evaluators: Optional[List[EvaluatorHparams]] = hp.optional(doc='Evaluators', default=None)
-    eval_batch_size: Optional[int] = hp.optional(doc='batch size to use for each evaluation step', default=None)
+    eval_batch_size: Optional[Union[int, str]] = hp.optional(doc='batch size to use for each evaluation step',
+                                                             default=None)
     eval_interval: Union[int, str] = hp.auto(Trainer, 'eval_interval')
     eval_subset_num_batches: int = hp.auto(Trainer, 'eval_subset_num_batches')
 
@@ -319,7 +331,6 @@ class TrainerHparams(hp.Hparams):
     run_name: Optional[str] = hp.auto(Trainer, 'run_name')
     progress_bar: bool = hp.auto(Trainer, 'progress_bar')
     log_to_console: Optional[bool] = hp.auto(Trainer, 'log_to_console')
-    console_log_level: LogLevel = hp.auto(Trainer, 'console_log_level')
     console_stream: str = hp.auto(Trainer, 'console_stream')
     python_log_level: str = hp.optional(doc='Python loglevel to use composer', default='INFO')
 
@@ -375,7 +386,11 @@ class TrainerHparams(hp.Hparams):
     # Profiling
     profiler: Optional[Profiler] = hp.auto(Trainer, 'profiler')
 
+    def __post_init__(self):
+        utils.warn_yahp_deprecation()
+
     def validate(self):
+
         super().validate()
 
         if self.deepspeed_config is not None:
@@ -395,6 +410,10 @@ class TrainerHparams(hp.Hparams):
             raise ValueError(
                 f'Batch size ({self.train_batch_size}) not divisible by the total number of processes ({world_size}).')
 
+        grad_accum = _parse_grad_accum(self.grad_accum)
+        if (isinstance(grad_accum, str) and grad_accum != 'auto') or (isinstance(grad_accum, int) and grad_accum < 1):
+            raise ValueError('grad_accum must be "auto" or an int greater than or equal to 1.')
+
         val_dataset_exists = self.val_dataset is not None
         evaluators_exist = self.evaluators is not None and len(self.evaluators) > 0
         if val_dataset_exists and evaluators_exist:
@@ -403,18 +422,23 @@ class TrainerHparams(hp.Hparams):
         if (val_dataset_exists or evaluators_exist) and self.eval_batch_size is None:
             raise ValueError('eval_batch_size must be specified if val_dataset or evaluators are specified.')
 
-        if self.eval_batch_size is not None and self.eval_batch_size % world_size != 0:
-            raise ValueError(
-                f'Eval batch size ({self.eval_batch_size}) not divisible by the total number of processes ({world_size}).'
-            )
+        eval_batch_size = _parse_eval_batch_size(self.eval_batch_size)
+        if eval_batch_size:
+            if (isinstance(eval_batch_size, str) and eval_batch_size != 'auto') or (isinstance(eval_batch_size, int) and
+                                                                                    eval_batch_size < 1):
+                raise ValueError(
+                    f'eval_batch_size must be "auto" or an int greater than or equal to 1 divisible by the number of processes ({world_size}).'
+                )
+            if eval_batch_size == 'auto' and grad_accum != 'auto':
+                raise ValueError('eval_batch_size can only be set to "auto" if grad_accum is also set to "auto"')
+            if eval_batch_size != 'auto' and eval_batch_size % world_size != 0:
+                raise ValueError(
+                    f'Eval batch size ({self.eval_batch_size}) not divisible by the total number of processes ({world_size}).'
+                )
 
         if self.scale_schedule_ratio <= 0:
             raise ValueError('scale_schedule_ratio must be a positive value.')
 
-        grad_accum = _parse_grad_accum(self.grad_accum)
-        if (isinstance(grad_accum, str) and grad_accum != 'auto') or (isinstance(grad_accum, int) and grad_accum < 1):
-            raise ValueError('grad_accum must be "auto" or an int greater than or equal to 1.')
-
     def initialize_object(self) -> Trainer:
         self.validate()
 
@@ -424,6 +448,11 @@ class TrainerHparams(hp.Hparams):
 
         # ensure grad_accum is 'auto' or an integer
         grad_accum = _parse_grad_accum(self.grad_accum)
+        eval_batch_size = _parse_eval_batch_size(self.eval_batch_size)
+        # _parse_eval_batch_size ensures eval_batch_size is auto if set to str. We need to check if
+        # it's a str and not eval_batch_size == 'auto' or pyright complains it might be a str still.
+        if isinstance(eval_batch_size, str):
+            eval_batch_size = self.train_batch_size
 
         # Device
         device = self.device
@@ -465,7 +494,7 @@ class TrainerHparams(hp.Hparams):
             model,
             self.val_dataset,
             self.evaluators,
-            self.eval_batch_size,
+            eval_batch_size,
             self.eval_subset_num_batches,
             self.dataloader,
         )
@@ -490,7 +519,6 @@ class TrainerHparams(hp.Hparams):
             # Train Data
             train_dataloader=train_dataloader,
             train_dataloader_label=self.train_dataloader_label,
-            compute_training_metrics=self.compute_training_metrics,
             train_subset_num_batches=self.train_subset_num_batches,
 
             # Stopping Condition
@@ -518,7 +546,6 @@ class TrainerHparams(hp.Hparams):
             run_name=self.run_name,
             progress_bar=self.progress_bar,
             log_to_console=self.log_to_console,
-            console_log_level=self.console_log_level,
             console_stream=self.console_stream,
 
             # Checkpoint Loading
@@ -592,7 +619,6 @@ class FitKwargs(TypedDict):
     train_dataloader: Optional[Union[Iterable, DataSpec, Dict[str, Any]]]
     train_dataloader_label: str
     train_subset_num_batches: Optional[int]
-    compute_training_metrics: Optional[bool]
 
     # Timing
     reset_time: bool
@@ -622,7 +648,6 @@ class FitHparams(hp.Hparams):
         train_batch_size (int, optional): The optimization batch size for the training dataset.
         train_dataloader_label (str, optional): See :meth:`.Trainer.fit`.
         train_subset_num_batches (int, optional): See :meth:`.Trainer.fit`.
-        compute_training_metrics (bool, optional): See :meth:`.Trainer.fit`.
         reset_time (bool, optional): See :meth:`.Trainer.fit`.
         duration (int | str, optional): See :meth:`.Trainer.fit`.
         schedulers (List[SchedulerHparams], optional): Scheduler hyperparameters.
@@ -652,7 +677,6 @@ class FitHparams(hp.Hparams):
     )
     train_dataloader_label: str = hp.auto(Trainer.fit, 'train_dataloader_label')
     train_subset_num_batches: Optional[int] = hp.auto(Trainer.fit, 'train_subset_num_batches')
-    compute_training_metrics: Optional[bool] = hp.auto(Trainer.fit, 'compute_training_metrics')
 
     # Timing
     reset_time: bool = hp.auto(Trainer.fit, 'reset_time')
@@ -712,7 +736,6 @@ class FitHparams(hp.Hparams):
             'train_dataloader': train_dataloader,
             'train_dataloader_label': self.train_dataloader_label,
             'train_subset_num_batches': self.train_subset_num_batches,
-            'compute_training_metrics': self.compute_training_metrics,
             'reset_time': self.reset_time,
             'duration': self.duration,
             'schedulers': self.schedulers,
@@ -731,11 +754,8 @@ class EvalKwargs(TypedDict):
 
     :meta private:
     """
-    dataloader: Union[Iterable, DataSpec, dict]
-    dataloader_label: str
-    metrics: Union[Metric, MetricCollection]
+    eval_dataloader: Optional[Union[Iterable, DataSpec, Evaluator, Sequence[Evaluator]]]
     subset_num_batches: int
-    log_level: Union[str, LogLevel]
 
 
 @dataclasses.dataclass
@@ -747,7 +767,6 @@ class EvalHparams(hp.Hparams):
         batch_size (int): The evaluation batch size across all workers.
         dataloader_label (str, optional): See :meth:`.Trainer.eval`.
         subset_num_batches (int, optional): See :meth:`.Trainer.eval`.
-        log_level (LogLevel, optional): See :meth:`.Trainer.eval`.
         metric_names (List[str], optional): Name of the metrics for the evaluator. (default: ``None``)
 
             Can be a :mod:`torchmetrics` metric name or the class name of a metric returned by
@@ -758,17 +777,12 @@ class EvalHparams(hp.Hparams):
     hparams_registry = {
         'dataset': dataset_registry,
     }
-    dataset: DatasetHparams = hp.required(doc='Validation dataset hparams')
-    batch_size: int = hp.required(doc='batch size to use for each evaluation step')
-    dataloader_label: str = hp.auto(Trainer.eval, 'dataloader_label')
-    subset_num_batches: int = hp.auto(Trainer.eval, 'subset_num_batches')
-    log_level: LogLevel = hp.auto(Trainer.eval, 'log_level')
-    metric_names: Optional[List[str]] = hp.optional(
-        doc=(
-            'Name of the metrics for the evaluator. Can be a torchmetrics metric name or the '
-            'class name of a metric returned by model.metrics(). If None (the default), uses all metrics in the model'),
-        default=None,
-    )
+
+    # Evaluation
+    dataset: Optional[DatasetHparams] = hp.optional(doc='Validation dataset hparams', default=None)
+    evaluators: Optional[List[EvaluatorHparams]] = hp.optional(doc='Evaluators', default=None)
+    batch_size: Optional[int] = hp.optional(doc='batch size to use for each evaluation step', default=None)
+    subset_num_batches: Optional[int] = hp.optional(doc='eval for this number of batches', default=None)
 
     def initialize_object(self, model: ComposerModel, dataloader_hparams: DataLoaderHparams) -> EvalKwargs:
         """Construct a kwargs dictionary that can be unpacked and passed into :meth:`.Trainer.eval`.
@@ -780,51 +794,22 @@ class EvalHparams(hp.Hparams):
         Returns:
             EvalKwargs: A kwargs dictionary that can be unpacked and passed into :meth:`.Trainer.eval`.
         """
-        # Dataloader
-        dataloader = _initialize_dataloader(
-            dataset_hparams=self.dataset,
-            dataloader_label=self.dataloader_label,
-            batch_size=self.batch_size,
-            subset_num_batches=self.subset_num_batches,
+        if self.subset_num_batches is None:
+            self.subset_num_batches = -1
+
+        # Eval dataloader
+        eval_dataloader = _initialize_eval_dataloader(
+            model=model,
+            eval_dataset_hparams=self.dataset,
+            evaluators=self.evaluators,
+            eval_batch_size=self.batch_size,
+            eval_subset_num_batches=self.subset_num_batches,
             dataloader_hparams=dataloader_hparams,
         )
-        assert dataloader is not None, 'The dataloader is a required argument'
-
-        # Metrics
-
-        # TODO(Ravi): Cleanup this code as part of the MetricsModule. This code was copied
-        # from composer/datasets/evaluator.py, but will likely be removed when the MetricsModule
-        # is implemented, as the trainer will not be responsible for constructing metrics.
-
-        # Get and copy all the model's associated evaluation metrics
-        model_metrics = model.metrics(train=False)
-        if isinstance(model_metrics, Metric):
-            # Forcing metrics to be a MetricCollection simplifies logging results
-            model_metrics = MetricCollection([model_metrics])
-
-        # Use all the metrics from the model if no metric_names are specified
-        if self.metric_names is None:
-            metrics = copy.deepcopy(model_metrics)
-        else:
-            metrics = MetricCollection([])
-            for metric_name in self.metric_names:
-                try:
-                    metric = model_metrics[metric_name]
-                except KeyError as e:
-                    raise RuntimeError((f'No metric found with the name {metric_name}. Check if this '
-                                        'metric is compatible/listed in your model metrics. ')) from e
-                assert isinstance(metric, Metric), 'all values of a MetricCollection.__getitem__ should be a metric'
-                metrics.add_metrics(copy.deepcopy(metric))
-            if len(metrics) == 0:
-                raise RuntimeError(('No metrics compatible with your model were added to this evaluator. '
-                                    'Check that the metrics you specified are compatible/listed in your model.'))
 
         return {
-            'dataloader': dataloader,
-            'dataloader_label': self.dataloader_label,
-            'metrics': metrics,
+            'eval_dataloader': eval_dataloader,
             'subset_num_batches': self.subset_num_batches,
-            'log_level': self.log_level,
         }
 
 
@@ -903,8 +888,7 @@ class ExperimentHparams(hp.Hparams):
                 (trainer, list of :meth:`~.Trainer.fit` kwargs, list of :meth:`~.Trainer.eval` kwargs).
         """
         trainer = self.trainer.initialize_object()
-        # TODO(ravi): With MetricsModule, `fit_hparams` and `eval_hparams` will
-        # no longer need the original model
+
         fit_kwargs = [
             fit_hparams.initialize_object(trainer._original_model, self.trainer.dataloader) for fit_hparams in self.fits
         ]
